@@ -54,6 +54,15 @@ static GOptionEntry options[] =
   { NULL }
 };
 
+static guint32
+parse_fourcc (const gchar *fourcc)
+{
+  if (strlen (fourcc) != 4)
+    return 0;
+
+  return GST_STR_FOURCC (fourcc);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -73,7 +82,6 @@ main (int argc, char *argv[])
   GstElement            *capsfilter;
   GstElement            *sink;
   GstCaps               *caps;
-  gchar                 *capsstr;
 
   result = clutter_gst_init_with_args (&argc,
                                        &argv,
@@ -143,9 +151,7 @@ main (int argc, char *argv[])
 
   g_object_set (capsfilter, "caps", caps, NULL);
 
-  capsstr = gst_caps_to_string (caps);
-  g_printf ("%s: [caps] %s\n", __FILE__, capsstr);
-  g_free (capsstr);
+  g_printf ("%s: [caps] %s\n", __FILE__, gst_caps_to_string (caps));
   gst_bin_add_many (GST_BIN (pipeline), src, capsfilter, sink, NULL);
   result = gst_element_link_many (src, capsfilter, sink, NULL);
   if (result == FALSE)
