@@ -64,7 +64,6 @@ main (int argc, char *argv[])
   GstElement       *capsfilter;
   GstElement       *sink;
   GstCaps          *caps;
-  ClutterGstPlayer *player;
 
   result = clutter_gst_init_with_args (&argc,
                                        &argv,
@@ -94,7 +93,7 @@ main (int argc, char *argv[])
   /* Video actor */
   actor = g_object_new (CLUTTER_TYPE_ACTOR,
                         "content", g_object_new (CLUTTER_GST_TYPE_CONTENT,
-                                                 "video-sink", sink,
+                                                 "sink", sink,
                                                  NULL),
                         "width", clutter_actor_get_width (stage),
                         "height", clutter_actor_get_height (stage),
